@@ -1,4 +1,4 @@
-/* $Id: demowindow.cc,v 1.11.2.3 2005/01/25 15:07:24 murrayc Exp $ */
+/* $Id: demowindow.cc,v 1.17.4.1 2006/05/10 14:49:31 murrayc Exp $ */
 
 /* Copyright (C) 2001 The gtkmm Development Team
  *
@@ -30,21 +30,17 @@
 #include <vector>
 #include <cctype>
 #include <cerrno>
-#include <stdio.h> //Needed by the SUN Forte compiler, for flockfile().
+#include <stdio.h>
 
-//The SUN Forte and Tru64 compilers can't seem to either find the declarations or the implementations,
-//so these are not used on that platform.
-//However, the configure time checks work, so HAVE_FLOCKFILE and HAVE_FUNLOCKFILE are defined.
-//This is a mystery.
-//
-//
-// In bug, #154973, Joel Fredrikson suggests defining _REENTRANT, but that does not make any difference,
-// and it's not clear that it is mean to solve this particular problem anyway.
-//
-//We #undef them so that this builds on non-g++ platforms:
-
-#undef HAVE_FLOCKFILE
-#undef HAVE_FUNLOCKFILE
+#ifdef NEED_FLOCKFILE_PROTO
+extern "C" void flockfile (FILE *);
+#endif
+#ifdef NEED_FUNLOCKFILE_PROTO
+extern "C" void funlockfile (FILE *);
+#endif
+#ifdef NEED_GETC_UNLOCKED_PROTO
+extern "C" int getc_unlocked (FILE *);
+#endif
 
 namespace
 {
@@ -132,11 +128,20 @@ void DemoWindow::fill_tree()
   }
 
   Gtk::CellRendererText* pCell = Gtk::manage(new Gtk::CellRendererText());
+#ifdef GLIBMM_PROPERTIES_ENABLED
   pCell->property_style() = Pango::STYLE_ITALIC;
+#else
+  pCell->set_property("style", Pango::STYLE_ITALIC);
+#endif
 
   Gtk::TreeViewColumn* pColumn = new Gtk::TreeViewColumn("Widget (double click for demo)", *pCell);
+#ifdef GLIBMM_PROPERTIES_ENABLED
   pColumn->add_attribute(pCell->property_text(), columns.title);
   pColumn->add_attribute(pCell->property_style_set(), columns.italic);
+#else
+  pColumn->add_attribute(*pCell, "text", columns.title);
+  pColumn->add_attribute(*pCell, "style_set", columns.italic);
+#endif
 
   m_TreeView.append_column(*pColumn);
 
@@ -187,7 +192,13 @@ void DemoWindow::on_treeselection_changed()
   if(const Gtk::TreeModel::iterator iter = m_refTreeSelection->get_selected())
   {
     const Glib::ustring filename = (*iter)[demo_columns().filename];
+
+    #ifdef GLIBMM_EXCEPTIONS_ENABLED
     load_file(Glib::filename_from_utf8(filename));
+    #else
+    std::auto_ptr<Glib::Error> error;
+    load_file(Glib::filename_from_utf8(filename, error));
+    #endif //GLIBMM_EXCEPTIONS_ENABLED
   }
 }
 
@@ -308,9 +319,6 @@ void DemoWindow::load_file(const std::string& filename)
     	    {
     	      Gtk::TextBuffer::iterator end = start;
 
-    	      // The SUN Forte compiler says this is a badly formed expression.
-            //g_assert (int(strlen(p)) >= (q - p)); //TODO: What is this for?  daniel.
-
               const Glib::ustring strTemp (p, q);
     	      end = refBufferInfo->insert(end, strTemp);
     	      start = end;
@@ -352,9 +360,6 @@ void DemoWindow::load_file(const std::string& filename)
                       start = refBufferInfo->insert(start, " ");
                     }
 
-                  // The SUN Forte compiler says this is a badly formed expression.
-                  // g_assert (int(strlen(p)) >= len); //TODO: What is this for?  daniel.
-
                   start = refBufferInfo->insert(start, Glib::ustring(p, p + len));
                   in_para = 1;
                 }
